change log for rtems-testing (2011-07-12)

rtems-vc at rtems.org rtems-vc at rtems.org
Tue Jul 12 14:10:02 UTC 2011


 *joel*:
2011-07-12	Joel Sherrill <joel.sherrill at oarcorp.com>

	* psxtmtest_single/init.c: Fix operation count and move timing to
	method.

M   1.15  rtems-test-template/ChangeLog
M    1.4  rtems-test-template/psxtmtest_single/init.c

diff -u rtems-testing/rtems-test-template/ChangeLog:1.14 rtems-testing/rtems-test-template/ChangeLog:1.15
--- rtems-testing/rtems-test-template/ChangeLog:1.14	Thu Jun 30 17:26:16 2011
+++ rtems-testing/rtems-test-template/ChangeLog	Tue Jul 12 08:20:03 2011
@@ -1,3 +1,8 @@
+2011-07-12	Joel Sherrill <joel.sherrill at oarcorp.com>
+
+	* psxtmtest_single/init.c: Fix operation count and move timing to
+	method.
+
 2011-06-30	Joel Sherrill <joel.sherrill at oarcorp.com>
 
 	* psxtmtest_blocking/init.c: Add tmacros.h

diff -u rtems-testing/rtems-test-template/psxtmtest_single/init.c:1.3 rtems-testing/rtems-test-template/psxtmtest_single/init.c:1.4
--- rtems-testing/rtems-test-template/psxtmtest_single/init.c:1.3	Mon Jun 13 14:28:14 2011
+++ rtems-testing/rtems-test-template/psxtmtest_single/init.c	Tue Jul 12 08:20:03 2011
@@ -17,30 +17,38 @@
 #include <rtems/timerdrv.h>
 #include "test_support.h"
 
-void *POSIX_Init(
-  void *argument
-)
+void benchmark_NAME_OF_OPERATION(void)
 {
   long end_time;
-
-  puts( "\n\n*** POSIX TIME TEST @UPPER@ ***" );
-
-  /* XXX any required initialization goes here */
+  int  status;
 
   benchmark_timer_initialize();
-
-  /* XXX single shot operation goes here */
-
+    /* XXX single shot operation goes here -- test expected status outside */
+    /* XXX of the benchmark'ed region */
   end_time = benchmark_timer_read();
+  rtems_test_assert( status == 0 );
 
   put_time(
     "@DESC@",
     end_time,
-    OPERATION_COUNT,
+    1,        /* Only executed once */
     0,
     0
   );
 
+}
+
+void *POSIX_Init(
+  void *argument
+)
+{
+
+  puts( "\n\n*** POSIX TIME TEST @UPPER@ ***" );
+
+  /* XXX any required initialization goes here */
+
+  benchmark_NAME_OF_OPERATION();
+  
   puts( "*** END OF POSIX TIME TEST @UPPER@ ***" );
 
   rtems_test_exit(0);



--

Generated by Deluxe Loginfo [http://www.codewiz.org/projects/index.html#loginfo] 2.122 by Bernardo Innocenti <bernie at develer.com>
-------------- next part --------------
An HTML attachment was scrubbed...
URL: <http://lists.rtems.org/pipermail/vc/attachments/20110712/b5297b88/attachment.html>


More information about the vc mailing list